Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(66)

Unified Diff: ash/common/wm/window_state.h

Issue 2778733004: Add WindowPinType property on arua::Window (Closed)
Patch Set: Address review issues. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/wm/maximize_mode/maximize_mode_window_state.cc ('k') | ash/common/wm/window_state.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/wm/window_state.h
diff --git a/ash/common/wm/window_state.h b/ash/common/wm/window_state.h
index 919e6b72e3f2c9b9dae235938cd7467e1c9d41b1..4763f5b1fc610f4b179628f17f56e3eca0059f4d 100644
--- a/ash/common/wm/window_state.h
+++ b/ash/common/wm/window_state.h
@@ -28,6 +28,10 @@ class LockWindowState;
class MaximizeModeWindowState;
class WmWindow;
+namespace mojom {
+enum class WindowPinType;
+}
+
namespace wm {
class WindowStateDelegate;
class WindowStateObserver;
@@ -319,6 +323,9 @@ class ASH_EXPORT WindowState {
// Called from the associated WmWindow once the show state changes.
void OnWindowShowStateChanged();
+ // Called from the associated WmWindow once the window pin type changes.
+ void OnWindowPinTypeChanged();
+
protected:
explicit WindowState(WmWindow* window);
@@ -338,6 +345,9 @@ class ASH_EXPORT WindowState {
// Returns the window's current show state.
ui::WindowShowState GetShowState() const;
+ // Return the window's current pin type.
+ ash::mojom::WindowPinType GetPinType() const;
+
// Sets the window's bounds in screen coordinates.
void SetBoundsInScreen(const gfx::Rect& bounds_in_screen);
@@ -345,9 +355,10 @@ class ASH_EXPORT WindowState {
// workspace if the window represented by |window_state| is side snapped.
void AdjustSnappedBounds(gfx::Rect* bounds);
// Updates the window show state according to the current window state type.
// Note that this does not update the window bounds.
- void UpdateWindowShowStateFromStateType();
+ void UpdateWindowPropertiesFromStateType();
void NotifyPreStateTypeChange(WindowStateType old_window_state_type);
void NotifyPostStateTypeChange(WindowStateType old_window_state_type);
« no previous file with comments | « ash/common/wm/maximize_mode/maximize_mode_window_state.cc ('k') | ash/common/wm/window_state.cc » ('j') | no next file with comments »
@@ -345,9 +355,10 @@ class ASH_EXPORT WindowState {
// workspace if the window represented by |window_state| is side snapped.
void AdjustSnappedBounds(gfx::Rect* bounds);
- // Updates the window show state according to the current window state type.
+ // Updates the window properties(show state, pin type) according to the
+ // current window state type.
// Note that this does not update the window bounds.

Powered by Google App Engine
This is Rietveld 408576698